@@ -10,12 +10,12 @@ if __name__ == "__main__":
     all = []
     print ''
     for i in xrange(50):
-        all.append(c.send_message('im-msg', u'你好', str(time.time()), i))
-        all.append(c.send_message('im-msg', 'hi', str(time.time()), i))
+        all.append(c.send_message('im-msg', u'你好'.encode('utf-8'), str(time.time()), str(i)))
+        all.append(c.send_message('im-msg', 'hi', str(time.time()), str(i)))
     print 'this will not block'
     for i in xrange(50):
-        all.append(c.send_message('im-msg', u'你好', str(time.time()), i))
-        all.append(c.send_message('im-msg', 'hi', str(time.time()), i))
+        all.append(c.send_message('im-msg', u'你好'.encode('utf-8'), str(time.time()), str(i)))
+        all.append(c.send_message('im-msg', 'hi', str(time.time()), str(i)))
     joinall(all)
     print 'but this will block'
     print time.time() - start
