@@ -9,11 +9,11 @@ if __name__ == "__main__":
     start = time.time()
     print ''
     for i in xrange(500):
-        c.send_message('im-msg', u'你好', str(time.time()), i)
-        c.send_message('im-msg', 'hi', str(time.time()), i)
+        c.send_message('im-msg', u'你好'.encode('utf8'), str(time.time()), str(i))
+        c.send_message('im-msg', 'hi', str(time.time()), str(i))
     for i in xrange(500):
-        c.send_message('im-msg', u'你好', str(time.time()), i)
-        c.send_message('im-msg', 'hi', str(time.time()), i)
+        c.send_message('im-msg', u'你好'.encode('utf8'), str(time.time()), str(i))
+        c.send_message('im-msg', 'hi', str(time.time()), str(i))
     print time.time() - start
     print 'this will not block'
     tornado.ioloop.IOLoop.instance().start()
